"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module
import builtins
import sys

if TYPE_CHECKING:
    from .deletebyorgapikeysbyidop import (
        DeleteByOrgAPIKeysByIDBadRequestError,
        DeleteByOrgAPIKeysByIDBadRequestErrorTypedDict,
        DeleteByOrgAPIKeysByIDConflictError,
        DeleteByOrgAPIKeysByIDConflictErrorTypedDict,
        DeleteByOrgAPIKeysByIDForbiddenError,
        DeleteByOrgAPIKeysByIDForbiddenErrorTypedDict,
        DeleteByOrgAPIKeysByIDInternalServerErrorError,
        DeleteByOrgAPIKeysByIDInternalServerErrorErrorTypedDict,
        DeleteByOrgAPIKeysByIDNotAcceptableError,
        DeleteByOrgAPIKeysByIDNotAcceptableErrorTypedDict,
        DeleteByOrgAPIKeysByIDNotFoundError,
        DeleteByOrgAPIKeysByIDNotFoundErrorTypedDict,
        DeleteByOrgAPIKeysByIDRequest,
        DeleteByOrgAPIKeysByIDRequestTypedDict,
        DeleteByOrgAPIKeysByIDResponse,
        DeleteByOrgAPIKeysByIDResponseTypedDict,
        DeleteByOrgAPIKeysByIDUnauthorizedError,
        DeleteByOrgAPIKeysByIDUnauthorizedErrorTypedDict,
    )
    from .deletebyorgbyrepobranchesbybranchop import (
        DeleteByOrgByRepoBranchesByBranchBadRequestError,
        DeleteByOrgByRepoBranchesByBranchBadRequestErrorTypedDict,
        DeleteByOrgByRepoBranchesByBranchConflictError,
        DeleteByOrgByRepoBranchesByBranchConflictErrorTypedDict,
        DeleteByOrgByRepoBranchesByBranchForbiddenError,
        DeleteByOrgByRepoBranchesByBranchForbiddenErrorTypedDict,
        DeleteByOrgByRepoBranchesByBranchInternalServerErrorError,
        DeleteByOrgByRepoBranchesByBranchInternalServerErrorErrorTypedDict,
        DeleteByOrgByRepoBranchesByBranchNotAcceptableError,
        DeleteByOrgByRepoBranchesByBranchNotAcceptableErrorTypedDict,
        DeleteByOrgByRepoBranchesByBranchNotFoundError,
        DeleteByOrgByRepoBranchesByBranchNotFoundErrorTypedDict,
        DeleteByOrgByRepoBranchesByBranchRequest,
        DeleteByOrgByRepoBranchesByBranchRequestTypedDict,
        DeleteByOrgByRepoBranchesByBranchResponse,
        DeleteByOrgByRepoBranchesByBranchResponseTypedDict,
        DeleteByOrgByRepoBranchesByBranchUnauthorizedError,
        DeleteByOrgByRepoBranchesByBranchUnauthorizedErrorTypedDict,
    )
    from .deletebyorgbyrepoop import (
        DeleteByOrgByRepoBadRequestError,
        DeleteByOrgByRepoBadRequestErrorTypedDict,
        DeleteByOrgByRepoConflictError,
        DeleteByOrgByRepoConflictErrorTypedDict,
        DeleteByOrgByRepoForbiddenError,
        DeleteByOrgByRepoForbiddenErrorTypedDict,
        DeleteByOrgByRepoInternalServerErrorError,
        DeleteByOrgByRepoInternalServerErrorErrorTypedDict,
        DeleteByOrgByRepoNotAcceptableError,
        DeleteByOrgByRepoNotAcceptableErrorTypedDict,
        DeleteByOrgByRepoNotFoundError,
        DeleteByOrgByRepoNotFoundErrorTypedDict,
        DeleteByOrgByRepoRequest,
        DeleteByOrgByRepoRequestTypedDict,
        DeleteByOrgByRepoResponse,
        DeleteByOrgByRepoResponseTypedDict,
        DeleteByOrgByRepoUnauthorizedError,
        DeleteByOrgByRepoUnauthorizedErrorTypedDict,
    )
    from .deletebyorgbyrepowebhooksbywebhookidop import (
        DeleteByOrgByRepoWebhooksByWebhookIDBadRequestError,
        DeleteByOrgByRepoWebhooksByWebhookIDBadRequestErrorTypedDict,
        DeleteByOrgByRepoWebhooksByWebhookIDConflictError,
        DeleteByOrgByRepoWebhooksByWebhookIDConflictErrorTypedDict,
        DeleteByOrgByRepoWebhooksByWebhookIDForbiddenError,
        DeleteByOrgByRepoWebhooksByWebhookIDForbiddenErrorTypedDict,
        DeleteByOrgByRepoWebhooksByWebhookIDInternalServerErrorError,
        DeleteByOrgByRepoWebhooksByWebhookIDInternalServerErrorErrorTypedDict,
        DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableError,
        DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableErrorTypedDict,
        DeleteByOrgByRepoWebhooksByWebhookIDNotFoundError,
        DeleteByOrgByRepoWebhooksByWebhookIDNotFoundErrorTypedDict,
        DeleteByOrgByRepoWebhooksByWebhookIDRequest,
        DeleteByOrgByRepoWebhooksByWebhookIDRequestTypedDict,
        DeleteByOrgByRepoWebhooksByWebhookIDResponse,
        DeleteByOrgByRepoWebhooksByWebhookIDResponseTypedDict,
        DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedError,
        DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedErrorTypedDict,
    )
    from .getbyorgapikeysop import (
        APIKey,
        APIKeyTypedDict,
        GetByOrgAPIKeysBadRequestError,
        GetByOrgAPIKeysBadRequestErrorTypedDict,
        GetByOrgAPIKeysConflictError,
        GetByOrgAPIKeysConflictErrorTypedDict,
        GetByOrgAPIKeysForbiddenError,
        GetByOrgAPIKeysForbiddenErrorTypedDict,
        GetByOrgAPIKeysInternalServerErrorError,
        GetByOrgAPIKeysInternalServerErrorErrorTypedDict,
        GetByOrgAPIKeysNotAcceptableError,
        GetByOrgAPIKeysNotAcceptableErrorTypedDict,
        GetByOrgAPIKeysNotFoundError,
        GetByOrgAPIKeysNotFoundErrorTypedDict,
        GetByOrgAPIKeysRequest,
        GetByOrgAPIKeysRequestTypedDict,
        GetByOrgAPIKeysResponse,
        GetByOrgAPIKeysResponseTypedDict,
        GetByOrgAPIKeysUnauthorizedError,
        GetByOrgAPIKeysUnauthorizedErrorTypedDict,
    )
    from .getbyorgbyrepoagentblameop import (
        Attribution,
        AttributionTypedDict,
        GetByOrgByRepoAgentblameBadRequestError,
        GetByOrgByRepoAgentblameBadRequestErrorTypedDict,
        GetByOrgByRepoAgentblameConflictError,
        GetByOrgByRepoAgentblameConflictErrorTypedDict,
        GetByOrgByRepoAgentblameForbiddenError,
        GetByOrgByRepoAgentblameForbiddenErrorTypedDict,
        GetByOrgByRepoAgentblameInternalServerErrorError,
        GetByOrgByRepoAgentblameInternalServerErrorErrorTypedDict,
        GetByOrgByRepoAgentblameNotAcceptableError,
        GetByOrgByRepoAgentblameNotAcceptableErrorTypedDict,
        GetByOrgByRepoAgentblameNotFoundError,
        GetByOrgByRepoAgentblameNotFoundErrorTypedDict,
        GetByOrgByRepoAgentblameRequest,
        GetByOrgByRepoAgentblameRequestTypedDict,
        GetByOrgByRepoAgentblameResponse,
        GetByOrgByRepoAgentblameResponseTypedDict,
        GetByOrgByRepoAgentblameStats,
        GetByOrgByRepoAgentblameStatsTypedDict,
        GetByOrgByRepoAgentblameUnauthorizedError,
        GetByOrgByRepoAgentblameUnauthorizedErrorTypedDict,
    )
    from .getbyorgbyrepoanalyticsop import (
        GetByOrgByRepoAnalyticsAnalytics,
        GetByOrgByRepoAnalyticsAnalyticsTypedDict,
        GetByOrgByRepoAnalyticsBadRequestError,
        GetByOrgByRepoAnalyticsBadRequestErrorTypedDict,
        GetByOrgByRepoAnalyticsConflictError,
        GetByOrgByRepoAnalyticsConflictErrorTypedDict,
        GetByOrgByRepoAnalyticsContributors,
        GetByOrgByRepoAnalyticsContributorsTypedDict,
        GetByOrgByRepoAnalyticsForbiddenError,
        GetByOrgByRepoAnalyticsForbiddenErrorTypedDict,
        GetByOrgByRepoAnalyticsHistory,
        GetByOrgByRepoAnalyticsHistoryTypedDict,
        GetByOrgByRepoAnalyticsInternalServerErrorError,
        GetByOrgByRepoAnalyticsInternalServerErrorErrorTypedDict,
        GetByOrgByRepoAnalyticsMeta,
        GetByOrgByRepoAnalyticsMetaTypedDict,
        GetByOrgByRepoAnalyticsNotAcceptableError,
        GetByOrgByRepoAnalyticsNotAcceptableErrorTypedDict,
        GetByOrgByRepoAnalyticsNotFoundError,
        GetByOrgByRepoAnalyticsNotFoundErrorTypedDict,
        GetByOrgByRepoAnalyticsRequest,
        GetByOrgByRepoAnalyticsRequestTypedDict,
        GetByOrgByRepoAnalyticsResponse,
        GetByOrgByRepoAnalyticsResponseTypedDict,
        GetByOrgByRepoAnalyticsStatus,
        GetByOrgByRepoAnalyticsSummary,
        GetByOrgByRepoAnalyticsSummaryTypedDict,
        GetByOrgByRepoAnalyticsUnauthorizedError,
        GetByOrgByRepoAnalyticsUnauthorizedErrorTypedDict,
        Period,
    )
    from .getbyorgbyrepobranchesop import (
        Branch,
        BranchTypedDict,
        GetByOrgByRepoBranchesBadRequestError,
        GetByOrgByRepoBranchesBadRequestErrorTypedDict,
        GetByOrgByRepoBranchesConflictError,
        GetByOrgByRepoBranchesConflictErrorTypedDict,
        GetByOrgByRepoBranchesForbiddenError,
        GetByOrgByRepoBranchesForbiddenErrorTypedDict,
        GetByOrgByRepoBranchesInternalServerErrorError,
        GetByOrgByRepoBranchesInternalServerErrorErrorTypedDict,
        GetByOrgByRepoBranchesNotAcceptableError,
        GetByOrgByRepoBranchesNotAcceptableErrorTypedDict,
        GetByOrgByRepoBranchesNotFoundError,
        GetByOrgByRepoBranchesNotFoundErrorTypedDict,
        GetByOrgByRepoBranchesRequest,
        GetByOrgByRepoBranchesRequestTypedDict,
        GetByOrgByRepoBranchesResponse,
        GetByOrgByRepoBranchesResponseBody,
        GetByOrgByRepoBranchesResponseBodyTypedDict,
        GetByOrgByRepoBranchesResponseTypedDict,
        GetByOrgByRepoBranchesUnauthorizedError,
        GetByOrgByRepoBranchesUnauthorizedErrorTypedDict,
    )
    from .getbyorgbyrepocommitsbyshaop import (
        GetByOrgByRepoCommitsByShaAuthor,
        GetByOrgByRepoCommitsByShaAuthorTypedDict,
        GetByOrgByRepoCommitsByShaBadRequestError,
        GetByOrgByRepoCommitsByShaBadRequestErrorTypedDict,
        GetByOrgByRepoCommitsByShaCommitter,
        GetByOrgByRepoCommitsByShaCommitterTypedDict,
        GetByOrgByRepoCommitsByShaConflictError,
        GetByOrgByRepoCommitsByShaConflictErrorTypedDict,
        GetByOrgByRepoCommitsByShaForbiddenError,
        GetByOrgByRepoCommitsByShaForbiddenErrorTypedDict,
        GetByOrgByRepoCommitsByShaInternalServerErrorError,
        GetByOrgByRepoCommitsByShaInternalServerErrorErrorTypedDict,
        GetByOrgByRepoCommitsByShaNotAcceptableError,
        GetByOrgByRepoCommitsByShaNotAcceptableErrorTypedDict,
        GetByOrgByRepoCommitsByShaNotFoundError,
        GetByOrgByRepoCommitsByShaNotFoundErrorTypedDict,
        GetByOrgByRepoCommitsByShaRequest,
        GetByOrgByRepoCommitsByShaRequestTypedDict,
        GetByOrgByRepoCommitsByShaResponse,
        GetByOrgByRepoCommitsByShaResponseTypedDict,
        GetByOrgByRepoCommitsByShaUnauthorizedError,
        GetByOrgByRepoCommitsByShaUnauthorizedErrorTypedDict,
    )
    from .getbyorgbyrepocommitsop import (
        Commit,
        CommitTypedDict,
        GetByOrgByRepoCommitsAuthor,
        GetByOrgByRepoCommitsAuthorTypedDict,
        GetByOrgByRepoCommitsBadRequestError,
        GetByOrgByRepoCommitsBadRequestErrorTypedDict,
        GetByOrgByRepoCommitsCommitter,
        GetByOrgByRepoCommitsCommitterTypedDict,
        GetByOrgByRepoCommitsConflictError,
        GetByOrgByRepoCommitsConflictErrorTypedDict,
        GetByOrgByRepoCommitsForbiddenError,
        GetByOrgByRepoCommitsForbiddenErrorTypedDict,
        GetByOrgByRepoCommitsInternalServerErrorError,
        GetByOrgByRepoCommitsInternalServerErrorErrorTypedDict,
        GetByOrgByRepoCommitsNotAcceptableError,
        GetByOrgByRepoCommitsNotAcceptableErrorTypedDict,
        GetByOrgByRepoCommitsNotFoundError,
        GetByOrgByRepoCommitsNotFoundErrorTypedDict,
        GetByOrgByRepoCommitsRequest,
        GetByOrgByRepoCommitsRequestTypedDict,
        GetByOrgByRepoCommitsResponse,
        GetByOrgByRepoCommitsResponseBody,
        GetByOrgByRepoCommitsResponseBodyTypedDict,
        GetByOrgByRepoCommitsResponseTypedDict,
        GetByOrgByRepoCommitsUnauthorizedError,
        GetByOrgByRepoCommitsUnauthorizedErrorTypedDict,
    )
    from .getbyorgbyrepocontentop import (
        Dir,
        DirTypedDict,
        Entry,
        EntryDir,
        EntryDirTypedDict,
        EntryFile,
        EntryFileTypedDict,
        EntrySymlink,
        EntrySymlinkTypedDict,
        EntryTypedDict,
        FileBase64,
        FileBase64TypedDict,
        GetByOrgByRepoContentBadRequestError,
        GetByOrgByRepoContentBadRequestErrorTypedDict,
        GetByOrgByRepoContentConflictError,
        GetByOrgByRepoContentConflictErrorTypedDict,
        GetByOrgByRepoContentForbiddenError,
        GetByOrgByRepoContentForbiddenErrorTypedDict,
        GetByOrgByRepoContentInternalServerErrorError,
        GetByOrgByRepoContentInternalServerErrorErrorTypedDict,
        GetByOrgByRepoContentNotAcceptableError,
        GetByOrgByRepoContentNotAcceptableErrorTypedDict,
        GetByOrgByRepoContentNotFoundError,
        GetByOrgByRepoContentNotFoundErrorTypedDict,
        GetByOrgByRepoContentRequest,
        GetByOrgByRepoContentRequestTypedDict,
        GetByOrgByRepoContentResponse,
        GetByOrgByRepoContentResponseBody,
        GetByOrgByRepoContentResponseBodyTypedDict,
        GetByOrgByRepoContentResponseTypedDict,
        GetByOrgByRepoContentUnauthorizedError,
        GetByOrgByRepoContentUnauthorizedErrorTypedDict,
        SymlinkBase64,
        SymlinkBase64TypedDict,
    )
    from .getbyorgbyrepodiffop import (
        FileStatus,
        FilteredFile,
        FilteredFileStatus,
        FilteredFileTypedDict,
        GetByOrgByRepoDiffBadRequestError,
        GetByOrgByRepoDiffBadRequestErrorTypedDict,
        GetByOrgByRepoDiffConflictError,
        GetByOrgByRepoDiffConflictErrorTypedDict,
        GetByOrgByRepoDiffFile,
        GetByOrgByRepoDiffFileTypedDict,
        GetByOrgByRepoDiffForbiddenError,
        GetByOrgByRepoDiffForbiddenErrorTypedDict,
        GetByOrgByRepoDiffInternalServerErrorError,
        GetByOrgByRepoDiffInternalServerErrorErrorTypedDict,
        GetByOrgByRepoDiffNotAcceptableError,
        GetByOrgByRepoDiffNotAcceptableErrorTypedDict,
        GetByOrgByRepoDiffNotFoundError,
        GetByOrgByRepoDiffNotFoundErrorTypedDict,
        GetByOrgByRepoDiffRequest,
        GetByOrgByRepoDiffRequestTypedDict,
        GetByOrgByRepoDiffResponse,
        GetByOrgByRepoDiffResponseBody,
        GetByOrgByRepoDiffResponseBodyTypedDict,
        GetByOrgByRepoDiffResponseTypedDict,
        GetByOrgByRepoDiffStats,
        GetByOrgByRepoDiffStatsTypedDict,
        GetByOrgByRepoDiffUnauthorizedError,
        GetByOrgByRepoDiffUnauthorizedErrorTypedDict,
    )
    from .getbyorgbyrepoop import (
        GetByOrgByRepoAutosync,
        GetByOrgByRepoAutosyncTypedDict,
        GetByOrgByRepoBadRequestError,
        GetByOrgByRepoBadRequestErrorTypedDict,
        GetByOrgByRepoConflictError,
        GetByOrgByRepoConflictErrorTypedDict,
        GetByOrgByRepoForbiddenError,
        GetByOrgByRepoForbiddenErrorTypedDict,
        GetByOrgByRepoInternalServerErrorError,
        GetByOrgByRepoInternalServerErrorErrorTypedDict,
        GetByOrgByRepoNotAcceptableError,
        GetByOrgByRepoNotAcceptableErrorTypedDict,
        GetByOrgByRepoNotFoundError,
        GetByOrgByRepoNotFoundErrorTypedDict,
        GetByOrgByRepoRequest,
        GetByOrgByRepoRequestTypedDict,
        GetByOrgByRepoResolutionStrategy,
        GetByOrgByRepoResponse,
        GetByOrgByRepoResponseTypedDict,
        GetByOrgByRepoUnauthorizedError,
        GetByOrgByRepoUnauthorizedErrorTypedDict,
        GetByOrgByRepoUpstream,
        GetByOrgByRepoUpstreamTypedDict,
    )
    from .getbyorgbyreposyncop import (
        GetByOrgByRepoSyncBadRequestError,
        GetByOrgByRepoSyncBadRequestErrorTypedDict,
        GetByOrgByRepoSyncConflictError,
        GetByOrgByRepoSyncConflictErrorTypedDict,
        GetByOrgByRepoSyncForbiddenError,
        GetByOrgByRepoSyncForbiddenErrorTypedDict,
        GetByOrgByRepoSyncInternalServerErrorError,
        GetByOrgByRepoSyncInternalServerErrorErrorTypedDict,
        GetByOrgByRepoSyncNotAcceptableError,
        GetByOrgByRepoSyncNotAcceptableErrorTypedDict,
        GetByOrgByRepoSyncNotFoundError,
        GetByOrgByRepoSyncNotFoundErrorTypedDict,
        GetByOrgByRepoSyncRequest,
        GetByOrgByRepoSyncRequestTypedDict,
        GetByOrgByRepoSyncResponse,
        GetByOrgByRepoSyncResponseTypedDict,
        GetByOrgByRepoSyncUnauthorizedError,
        GetByOrgByRepoSyncUnauthorizedErrorTypedDict,
        Status,
        StatusError,
        StatusErrorTypedDict,
        StatusOk,
        StatusOkTypedDict,
        StatusTypedDict,
    )
    from .getbyorgbyrepowebhooksop import (
        GetByOrgByRepoWebhooksBadRequestError,
        GetByOrgByRepoWebhooksBadRequestErrorTypedDict,
        GetByOrgByRepoWebhooksConflictError,
        GetByOrgByRepoWebhooksConflictErrorTypedDict,
        GetByOrgByRepoWebhooksEvent,
        GetByOrgByRepoWebhooksForbiddenError,
        GetByOrgByRepoWebhooksForbiddenErrorTypedDict,
        GetByOrgByRepoWebhooksInternalServerErrorError,
        GetByOrgByRepoWebhooksInternalServerErrorErrorTypedDict,
        GetByOrgByRepoWebhooksNotAcceptableError,
        GetByOrgByRepoWebhooksNotAcceptableErrorTypedDict,
        GetByOrgByRepoWebhooksNotFoundError,
        GetByOrgByRepoWebhooksNotFoundErrorTypedDict,
        GetByOrgByRepoWebhooksRequest,
        GetByOrgByRepoWebhooksRequestTypedDict,
        GetByOrgByRepoWebhooksResponse,
        GetByOrgByRepoWebhooksResponseTypedDict,
        GetByOrgByRepoWebhooksUnauthorizedError,
        GetByOrgByRepoWebhooksUnauthorizedErrorTypedDict,
        Webhook,
        WebhookTypedDict,
    )
    from .getbyorgop import (
        GetByOrgBadRequestError,
        GetByOrgBadRequestErrorTypedDict,
        GetByOrgConflictError,
        GetByOrgConflictErrorTypedDict,
        GetByOrgForbiddenError,
        GetByOrgForbiddenErrorTypedDict,
        GetByOrgInternalServerErrorError,
        GetByOrgInternalServerErrorErrorTypedDict,
        GetByOrgNotAcceptableError,
        GetByOrgNotAcceptableErrorTypedDict,
        GetByOrgNotFoundError,
        GetByOrgNotFoundErrorTypedDict,
        GetByOrgRequest,
        GetByOrgRequestTypedDict,
        GetByOrgResponse,
        GetByOrgResponseTypedDict,
        GetByOrgUnauthorizedError,
        GetByOrgUnauthorizedErrorTypedDict,
    )
    from .getbyorgreposop import (
        GetByOrgReposAutosync,
        GetByOrgReposAutosyncTypedDict,
        GetByOrgReposBadRequestError,
        GetByOrgReposBadRequestErrorTypedDict,
        GetByOrgReposConflictError,
        GetByOrgReposConflictErrorTypedDict,
        GetByOrgReposForbiddenError,
        GetByOrgReposForbiddenErrorTypedDict,
        GetByOrgReposInternalServerErrorError,
        GetByOrgReposInternalServerErrorErrorTypedDict,
        GetByOrgReposNotAcceptableError,
        GetByOrgReposNotAcceptableErrorTypedDict,
        GetByOrgReposNotFoundError,
        GetByOrgReposNotFoundErrorTypedDict,
        GetByOrgReposRequest,
        GetByOrgReposRequestTypedDict,
        GetByOrgReposResolutionStrategy,
        GetByOrgReposResponse,
        GetByOrgReposResponseBody,
        GetByOrgReposResponseBodyTypedDict,
        GetByOrgReposResponseTypedDict,
        GetByOrgReposUnauthorizedError,
        GetByOrgReposUnauthorizedErrorTypedDict,
        GetByOrgReposUpstream,
        GetByOrgReposUpstreamTypedDict,
        Repo,
        RepoTypedDict,
    )
    from .patchbyorgbyrepoop import (
        PatchByOrgByRepoAutosyncPollRequest,
        PatchByOrgByRepoAutosyncPollRequestTypedDict,
        PatchByOrgByRepoAutosyncResponse,
        PatchByOrgByRepoAutosyncResponseTypedDict,
        PatchByOrgByRepoAutosyncUnion,
        PatchByOrgByRepoAutosyncUnionTypedDict,
        PatchByOrgByRepoBadRequestError,
        PatchByOrgByRepoBadRequestErrorTypedDict,
        PatchByOrgByRepoConflictError,
        PatchByOrgByRepoConflictErrorTypedDict,
        PatchByOrgByRepoForbiddenError,
        PatchByOrgByRepoForbiddenErrorTypedDict,
        PatchByOrgByRepoInternalServerErrorError,
        PatchByOrgByRepoInternalServerErrorErrorTypedDict,
        PatchByOrgByRepoNotAcceptableError,
        PatchByOrgByRepoNotAcceptableErrorTypedDict,
        PatchByOrgByRepoNotFoundError,
        PatchByOrgByRepoNotFoundErrorTypedDict,
        PatchByOrgByRepoRequest,
        PatchByOrgByRepoRequestBody,
        PatchByOrgByRepoRequestBodyTypedDict,
        PatchByOrgByRepoRequestTypedDict,
        PatchByOrgByRepoResolutionStrategyRequest,
        PatchByOrgByRepoResolutionStrategyResponse,
        PatchByOrgByRepoResponse,
        PatchByOrgByRepoResponseTypedDict,
        PatchByOrgByRepoUnauthorizedError,
        PatchByOrgByRepoUnauthorizedErrorTypedDict,
        PatchByOrgByRepoUpstreamRequest,
        PatchByOrgByRepoUpstreamRequestTypedDict,
        PatchByOrgByRepoUpstreamResponse,
        PatchByOrgByRepoUpstreamResponseTypedDict,
    )
    from .postbyorgapikeysop import (
        PostByOrgAPIKeysBadRequestError,
        PostByOrgAPIKeysBadRequestErrorTypedDict,
        PostByOrgAPIKeysConflictError,
        PostByOrgAPIKeysConflictErrorTypedDict,
        PostByOrgAPIKeysForbiddenError,
        PostByOrgAPIKeysForbiddenErrorTypedDict,
        PostByOrgAPIKeysInternalServerErrorError,
        PostByOrgAPIKeysInternalServerErrorErrorTypedDict,
        PostByOrgAPIKeysNotAcceptableError,
        PostByOrgAPIKeysNotAcceptableErrorTypedDict,
        PostByOrgAPIKeysNotFoundError,
        PostByOrgAPIKeysNotFoundErrorTypedDict,
        PostByOrgAPIKeysRequest,
        PostByOrgAPIKeysRequestBody,
        PostByOrgAPIKeysRequestBodyTypedDict,
        PostByOrgAPIKeysRequestTypedDict,
        PostByOrgAPIKeysResponse,
        PostByOrgAPIKeysResponseTypedDict,
        PostByOrgAPIKeysUnauthorizedError,
        PostByOrgAPIKeysUnauthorizedErrorTypedDict,
        Scope,
    )
    from .postbyorgbyrepoanalyticsrefreshop import (
        PostByOrgByRepoAnalyticsRefreshAnalytics,
        PostByOrgByRepoAnalyticsRefreshAnalyticsTypedDict,
        PostByOrgByRepoAnalyticsRefreshBadRequestError,
        PostByOrgByRepoAnalyticsRefreshBadRequestErrorTypedDict,
        PostByOrgByRepoAnalyticsRefreshConflictError,
        PostByOrgByRepoAnalyticsRefreshConflictErrorTypedDict,
        PostByOrgByRepoAnalyticsRefreshContributors,
        PostByOrgByRepoAnalyticsRefreshContributorsTypedDict,
        PostByOrgByRepoAnalyticsRefreshForbiddenError,
        PostByOrgByRepoAnalyticsRefreshForbiddenErrorTypedDict,
        PostByOrgByRepoAnalyticsRefreshHistory,
        PostByOrgByRepoAnalyticsRefreshHistoryTypedDict,
        PostByOrgByRepoAnalyticsRefreshInternalServerErrorError,
        PostByOrgByRepoAnalyticsRefreshInternalServerErrorErrorTypedDict,
        PostByOrgByRepoAnalyticsRefreshMeta,
        PostByOrgByRepoAnalyticsRefreshMetaTypedDict,
        PostByOrgByRepoAnalyticsRefreshNotAcceptableError,
        PostByOrgByRepoAnalyticsRefreshNotAcceptableErrorTypedDict,
        PostByOrgByRepoAnalyticsRefreshNotFoundError,
        PostByOrgByRepoAnalyticsRefreshNotFoundErrorTypedDict,
        PostByOrgByRepoAnalyticsRefreshRequest,
        PostByOrgByRepoAnalyticsRefreshRequestTypedDict,
        PostByOrgByRepoAnalyticsRefreshResponse,
        PostByOrgByRepoAnalyticsRefreshResponseTypedDict,
        PostByOrgByRepoAnalyticsRefreshStatus,
        PostByOrgByRepoAnalyticsRefreshSummary,
        PostByOrgByRepoAnalyticsRefreshSummaryTypedDict,
        PostByOrgByRepoAnalyticsRefreshUnauthorizedError,
        PostByOrgByRepoAnalyticsRefreshUnauthorizedErrorTypedDict,
    )
    from .postbyorgbyrepobranchesop import (
        PostByOrgByRepoBranchesBadRequestError,
        PostByOrgByRepoBranchesBadRequestErrorTypedDict,
        PostByOrgByRepoBranchesConflictError,
        PostByOrgByRepoBranchesConflictErrorTypedDict,
        PostByOrgByRepoBranchesForbiddenError,
        PostByOrgByRepoBranchesForbiddenErrorTypedDict,
        PostByOrgByRepoBranchesInternalServerErrorError,
        PostByOrgByRepoBranchesInternalServerErrorErrorTypedDict,
        PostByOrgByRepoBranchesNotAcceptableError,
        PostByOrgByRepoBranchesNotAcceptableErrorTypedDict,
        PostByOrgByRepoBranchesNotFoundError,
        PostByOrgByRepoBranchesNotFoundErrorTypedDict,
        PostByOrgByRepoBranchesRequest,
        PostByOrgByRepoBranchesRequestBody,
        PostByOrgByRepoBranchesRequestBodyTypedDict,
        PostByOrgByRepoBranchesRequestTypedDict,
        PostByOrgByRepoBranchesResponse,
        PostByOrgByRepoBranchesResponseTypedDict,
        PostByOrgByRepoBranchesUnauthorizedError,
        PostByOrgByRepoBranchesUnauthorizedErrorTypedDict,
    )
    from .postbyorgbyrepocommitsop import (
        Encoding,
        File,
        FileDelete,
        FileDeleteTypedDict,
        FileTypedDict,
        FileUpsert,
        FileUpsertTypedDict,
        PostByOrgByRepoCommitsAuthor,
        PostByOrgByRepoCommitsAuthorTypedDict,
        PostByOrgByRepoCommitsBadRequestError,
        PostByOrgByRepoCommitsBadRequestErrorTypedDict,
        PostByOrgByRepoCommitsConflictError,
        PostByOrgByRepoCommitsConflictErrorTypedDict,
        PostByOrgByRepoCommitsForbiddenError,
        PostByOrgByRepoCommitsForbiddenErrorTypedDict,
        PostByOrgByRepoCommitsInternalServerErrorError,
        PostByOrgByRepoCommitsInternalServerErrorErrorTypedDict,
        PostByOrgByRepoCommitsNotAcceptableError,
        PostByOrgByRepoCommitsNotAcceptableErrorTypedDict,
        PostByOrgByRepoCommitsNotFoundError,
        PostByOrgByRepoCommitsNotFoundErrorTypedDict,
        PostByOrgByRepoCommitsRequest,
        PostByOrgByRepoCommitsRequestBody,
        PostByOrgByRepoCommitsRequestBodyTypedDict,
        PostByOrgByRepoCommitsRequestTypedDict,
        PostByOrgByRepoCommitsResponse,
        PostByOrgByRepoCommitsResponseTypedDict,
        PostByOrgByRepoCommitsUnauthorizedError,
        PostByOrgByRepoCommitsUnauthorizedErrorTypedDict,
    )
    from .postbyorgbyreposyncop import (
        PostByOrgByRepoSyncBadRequestError,
        PostByOrgByRepoSyncBadRequestErrorTypedDict,
        PostByOrgByRepoSyncConflictError,
        PostByOrgByRepoSyncConflictErrorTypedDict,
        PostByOrgByRepoSyncForbiddenError,
        PostByOrgByRepoSyncForbiddenErrorTypedDict,
        PostByOrgByRepoSyncInternalServerErrorError,
        PostByOrgByRepoSyncInternalServerErrorErrorTypedDict,
        PostByOrgByRepoSyncNotAcceptableError,
        PostByOrgByRepoSyncNotAcceptableErrorTypedDict,
        PostByOrgByRepoSyncNotFoundError,
        PostByOrgByRepoSyncNotFoundErrorTypedDict,
        PostByOrgByRepoSyncRequest,
        PostByOrgByRepoSyncRequestTypedDict,
        PostByOrgByRepoSyncResponse,
        PostByOrgByRepoSyncResponseTypedDict,
        PostByOrgByRepoSyncUnauthorizedError,
        PostByOrgByRepoSyncUnauthorizedErrorTypedDict,
    )
    from .postbyorgbyrepowebhooksop import (
        EventRequest,
        PostByOrgByRepoWebhooksBadRequestError,
        PostByOrgByRepoWebhooksBadRequestErrorTypedDict,
        PostByOrgByRepoWebhooksConflictError,
        PostByOrgByRepoWebhooksConflictErrorTypedDict,
        PostByOrgByRepoWebhooksEventResponse,
        PostByOrgByRepoWebhooksForbiddenError,
        PostByOrgByRepoWebhooksForbiddenErrorTypedDict,
        PostByOrgByRepoWebhooksInternalServerErrorError,
        PostByOrgByRepoWebhooksInternalServerErrorErrorTypedDict,
        PostByOrgByRepoWebhooksNotAcceptableError,
        PostByOrgByRepoWebhooksNotAcceptableErrorTypedDict,
        PostByOrgByRepoWebhooksNotFoundError,
        PostByOrgByRepoWebhooksNotFoundErrorTypedDict,
        PostByOrgByRepoWebhooksRequest,
        PostByOrgByRepoWebhooksRequestBody,
        PostByOrgByRepoWebhooksRequestBodyTypedDict,
        PostByOrgByRepoWebhooksRequestTypedDict,
        PostByOrgByRepoWebhooksResponse,
        PostByOrgByRepoWebhooksResponseTypedDict,
        PostByOrgByRepoWebhooksUnauthorizedError,
        PostByOrgByRepoWebhooksUnauthorizedErrorTypedDict,
    )
    from .postbyorgreposop import (
        PostByOrgReposAutosyncPollRequest,
        PostByOrgReposAutosyncPollRequestTypedDict,
        PostByOrgReposAutosyncResponse,
        PostByOrgReposAutosyncResponseTypedDict,
        PostByOrgReposAutosyncUnion,
        PostByOrgReposAutosyncUnionTypedDict,
        PostByOrgReposBadRequestError,
        PostByOrgReposBadRequestErrorTypedDict,
        PostByOrgReposConflictError,
        PostByOrgReposConflictErrorTypedDict,
        PostByOrgReposForbiddenError,
        PostByOrgReposForbiddenErrorTypedDict,
        PostByOrgReposInternalServerErrorError,
        PostByOrgReposInternalServerErrorErrorTypedDict,
        PostByOrgReposNotAcceptableError,
        PostByOrgReposNotAcceptableErrorTypedDict,
        PostByOrgReposNotFoundError,
        PostByOrgReposNotFoundErrorTypedDict,
        PostByOrgReposRequest,
        PostByOrgReposRequestBody,
        PostByOrgReposRequestBodyTypedDict,
        PostByOrgReposRequestTypedDict,
        PostByOrgReposResolutionStrategyRequest,
        PostByOrgReposResolutionStrategyResponse,
        PostByOrgReposResponse,
        PostByOrgReposResponseTypedDict,
        PostByOrgReposUnauthorizedError,
        PostByOrgReposUnauthorizedErrorTypedDict,
        PostByOrgReposUpstreamRequest,
        PostByOrgReposUpstreamRequestTypedDict,
        PostByOrgReposUpstreamResponse,
        PostByOrgReposUpstreamResponseTypedDict,
    )
    from .security import Security, SecurityTypedDict

__all__ = [
    "APIKey",
    "APIKeyTypedDict",
    "Attribution",
    "AttributionTypedDict",
    "Branch",
    "BranchTypedDict",
    "Commit",
    "CommitTypedDict",
    "DeleteByOrgAPIKeysByIDBadRequestError",
    "DeleteByOrgAPIKeysByIDBadRequestErrorTypedDict",
    "DeleteByOrgAPIKeysByIDConflictError",
    "DeleteByOrgAPIKeysByIDConflictErrorTypedDict",
    "DeleteByOrgAPIKeysByIDForbiddenError",
    "DeleteByOrgAPIKeysByIDForbiddenErrorTypedDict",
    "DeleteByOrgAPIKeysByIDInternalServerErrorError",
    "DeleteByOrgAPIKeysByIDInternalServerErrorErrorTypedDict",
    "DeleteByOrgAPIKeysByIDNotAcceptableError",
    "DeleteByOrgAPIKeysByIDNotAcceptableErrorTypedDict",
    "DeleteByOrgAPIKeysByIDNotFoundError",
    "DeleteByOrgAPIKeysByIDNotFoundErrorTypedDict",
    "DeleteByOrgAPIKeysByIDRequest",
    "DeleteByOrgAPIKeysByIDRequestTypedDict",
    "DeleteByOrgAPIKeysByIDResponse",
    "DeleteByOrgAPIKeysByIDResponseTypedDict",
    "DeleteByOrgAPIKeysByIDUnauthorizedError",
    "DeleteByOrgAPIKeysByIDUnauthorizedErrorTypedDict",
    "DeleteByOrgByRepoBadRequestError",
    "DeleteByOrgByRepoBadRequestErrorTypedDict",
    "DeleteByOrgByRepoBranchesByBranchBadRequestError",
    "DeleteByOrgByRepoBranchesByBranchBadRequestErrorTypedDict",
    "DeleteByOrgByRepoBranchesByBranchConflictError",
    "DeleteByOrgByRepoBranchesByBranchConflictErrorTypedDict",
    "DeleteByOrgByRepoBranchesByBranchForbiddenError",
    "DeleteByOrgByRepoBranchesByBranchForbiddenErrorTypedDict",
    "DeleteByOrgByRepoBranchesByBranchInternalServerErrorError",
    "DeleteByOrgByRepoBranchesByBranchInternalServerErrorErrorTypedDict",
    "DeleteByOrgByRepoBranchesByBranchNotAcceptableError",
    "DeleteByOrgByRepoBranchesByBranchNotAcceptableErrorTypedDict",
    "DeleteByOrgByRepoBranchesByBranchNotFoundError",
    "DeleteByOrgByRepoBranchesByBranchNotFoundErrorTypedDict",
    "DeleteByOrgByRepoBranchesByBranchRequest",
    "DeleteByOrgByRepoBranchesByBranchRequestTypedDict",
    "DeleteByOrgByRepoBranchesByBranchResponse",
    "DeleteByOrgByRepoBranchesByBranchResponseTypedDict",
    "DeleteByOrgByRepoBranchesByBranchUnauthorizedError",
    "DeleteByOrgByRepoBranchesByBranchUnauthorizedErrorTypedDict",
    "DeleteByOrgByRepoConflictError",
    "DeleteByOrgByRepoConflictErrorTypedDict",
    "DeleteByOrgByRepoForbiddenError",
    "DeleteByOrgByRepoForbiddenErrorTypedDict",
    "DeleteByOrgByRepoInternalServerErrorError",
    "DeleteByOrgByRepoInternalServerErrorErrorTypedDict",
    "DeleteByOrgByRepoNotAcceptableError",
    "DeleteByOrgByRepoNotAcceptableErrorTypedDict",
    "DeleteByOrgByRepoNotFoundError",
    "DeleteByOrgByRepoNotFoundErrorTypedDict",
    "DeleteByOrgByRepoRequest",
    "DeleteByOrgByRepoRequestTypedDict",
    "DeleteByOrgByRepoResponse",
    "DeleteByOrgByRepoResponseTypedDict",
    "DeleteByOrgByRepoUnauthorizedError",
    "DeleteByOrgByRepoUnauthorizedErrorTypedDict",
    "DeleteByOrgByRepoWebhooksByWebhookIDBadRequestError",
    "DeleteByOrgByRepoWebhooksByWebhookIDBadRequestErrorTypedDict",
    "DeleteByOrgByRepoWebhooksByWebhookIDConflictError",
    "DeleteByOrgByRepoWebhooksByWebhookIDConflictErrorTypedDict",
    "DeleteByOrgByRepoWebhooksByWebhookIDForbiddenError",
    "DeleteByOrgByRepoWebhooksByWebhookIDForbiddenErrorTypedDict",
    "DeleteByOrgByRepoWebhooksByWebhookIDInternalServerErrorError",
    "DeleteByOrgByRepoWebhooksByWebhookIDInternalServerErrorErrorTypedDict",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableError",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableErrorTypedDict",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotFoundError",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotFoundErrorTypedDict",
    "DeleteByOrgByRepoWebhooksByWebhookIDRequest",
    "DeleteByOrgByRepoWebhooksByWebhookIDRequestTypedDict",
    "DeleteByOrgByRepoWebhooksByWebhookIDResponse",
    "DeleteByOrgByRepoWebhooksByWebhookIDResponseTypedDict",
    "DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedError",
    "DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedErrorTypedDict",
    "Dir",
    "DirTypedDict",
    "Encoding",
    "Entry",
    "EntryDir",
    "EntryDirTypedDict",
    "EntryFile",
    "EntryFileTypedDict",
    "EntrySymlink",
    "EntrySymlinkTypedDict",
    "EntryTypedDict",
    "EventRequest",
    "File",
    "FileBase64",
    "FileBase64TypedDict",
    "FileDelete",
    "FileDeleteTypedDict",
    "FileStatus",
    "FileTypedDict",
    "FileUpsert",
    "FileUpsertTypedDict",
    "FilteredFile",
    "FilteredFileStatus",
    "FilteredFileTypedDict",
    "GetByOrgAPIKeysBadRequestError",
    "GetByOrgAPIKeysBadRequestErrorTypedDict",
    "GetByOrgAPIKeysConflictError",
    "GetByOrgAPIKeysConflictErrorTypedDict",
    "GetByOrgAPIKeysForbiddenError",
    "GetByOrgAPIKeysForbiddenErrorTypedDict",
    "GetByOrgAPIKeysInternalServerErrorError",
    "GetByOrgAPIKeysInternalServerErrorErrorTypedDict",
    "GetByOrgAPIKeysNotAcceptableError",
    "GetByOrgAPIKeysNotAcceptableErrorTypedDict",
    "GetByOrgAPIKeysNotFoundError",
    "GetByOrgAPIKeysNotFoundErrorTypedDict",
    "GetByOrgAPIKeysRequest",
    "GetByOrgAPIKeysRequestTypedDict",
    "GetByOrgAPIKeysResponse",
    "GetByOrgAPIKeysResponseTypedDict",
    "GetByOrgAPIKeysUnauthorizedError",
    "GetByOrgAPIKeysUnauthorizedErrorTypedDict",
    "GetByOrgBadRequestError",
    "GetByOrgBadRequestErrorTypedDict",
    "GetByOrgByRepoAgentblameBadRequestError",
    "GetByOrgByRepoAgentblameBadRequestErrorTypedDict",
    "GetByOrgByRepoAgentblameConflictError",
    "GetByOrgByRepoAgentblameConflictErrorTypedDict",
    "GetByOrgByRepoAgentblameForbiddenError",
    "GetByOrgByRepoAgentblameForbiddenErrorTypedDict",
    "GetByOrgByRepoAgentblameInternalServerErrorError",
    "GetByOrgByRepoAgentblameInternalServerErrorErrorTypedDict",
    "GetByOrgByRepoAgentblameNotAcceptableError",
    "GetByOrgByRepoAgentblameNotAcceptableErrorTypedDict",
    "GetByOrgByRepoAgentblameNotFoundError",
    "GetByOrgByRepoAgentblameNotFoundErrorTypedDict",
    "GetByOrgByRepoAgentblameRequest",
    "GetByOrgByRepoAgentblameRequestTypedDict",
    "GetByOrgByRepoAgentblameResponse",
    "GetByOrgByRepoAgentblameResponseTypedDict",
    "GetByOrgByRepoAgentblameStats",
    "GetByOrgByRepoAgentblameStatsTypedDict",
    "GetByOrgByRepoAgentblameUnauthorizedError",
    "GetByOrgByRepoAgentblameUnauthorizedErrorTypedDict",
    "GetByOrgByRepoAnalyticsAnalytics",
    "GetByOrgByRepoAnalyticsAnalyticsTypedDict",
    "GetByOrgByRepoAnalyticsBadRequestError",
    "GetByOrgByRepoAnalyticsBadRequestErrorTypedDict",
    "GetByOrgByRepoAnalyticsConflictError",
    "GetByOrgByRepoAnalyticsConflictErrorTypedDict",
    "GetByOrgByRepoAnalyticsContributors",
    "GetByOrgByRepoAnalyticsContributorsTypedDict",
    "GetByOrgByRepoAnalyticsForbiddenError",
    "GetByOrgByRepoAnalyticsForbiddenErrorTypedDict",
    "GetByOrgByRepoAnalyticsHistory",
    "GetByOrgByRepoAnalyticsHistoryTypedDict",
    "GetByOrgByRepoAnalyticsInternalServerErrorError",
    "GetByOrgByRepoAnalyticsInternalServerErrorErrorTypedDict",
    "GetByOrgByRepoAnalyticsMeta",
    "GetByOrgByRepoAnalyticsMetaTypedDict",
    "GetByOrgByRepoAnalyticsNotAcceptableError",
    "GetByOrgByRepoAnalyticsNotAcceptableErrorTypedDict",
    "GetByOrgByRepoAnalyticsNotFoundError",
    "GetByOrgByRepoAnalyticsNotFoundErrorTypedDict",
    "GetByOrgByRepoAnalyticsRequest",
    "GetByOrgByRepoAnalyticsRequestTypedDict",
    "GetByOrgByRepoAnalyticsResponse",
    "GetByOrgByRepoAnalyticsResponseTypedDict",
    "GetByOrgByRepoAnalyticsStatus",
    "GetByOrgByRepoAnalyticsSummary",
    "GetByOrgByRepoAnalyticsSummaryTypedDict",
    "GetByOrgByRepoAnalyticsUnauthorizedError",
    "GetByOrgByRepoAnalyticsUnauthorizedErrorTypedDict",
    "GetByOrgByRepoAutosync",
    "GetByOrgByRepoAutosyncTypedDict",
    "GetByOrgByRepoBadRequestError",
    "GetByOrgByRepoBadRequestErrorTypedDict",
    "GetByOrgByRepoBranchesBadRequestError",
    "GetByOrgByRepoBranchesBadRequestErrorTypedDict",
    "GetByOrgByRepoBranchesConflictError",
    "GetByOrgByRepoBranchesConflictErrorTypedDict",
    "GetByOrgByRepoBranchesForbiddenError",
    "GetByOrgByRepoBranchesForbiddenErrorTypedDict",
    "GetByOrgByRepoBranchesInternalServerErrorError",
    "GetByOrgByRepoBranchesInternalServerErrorErrorTypedDict",
    "GetByOrgByRepoBranchesNotAcceptableError",
    "GetByOrgByRepoBranchesNotAcceptableErrorTypedDict",
    "GetByOrgByRepoBranchesNotFoundError",
    "GetByOrgByRepoBranchesNotFoundErrorTypedDict",
    "GetByOrgByRepoBranchesRequest",
    "GetByOrgByRepoBranchesRequestTypedDict",
    "GetByOrgByRepoBranchesResponse",
    "GetByOrgByRepoBranchesResponseBody",
    "GetByOrgByRepoBranchesResponseBodyTypedDict",
    "GetByOrgByRepoBranchesResponseTypedDict",
    "GetByOrgByRepoBranchesUnauthorizedError",
    "GetByOrgByRepoBranchesUnauthorizedErrorTypedDict",
    "GetByOrgByRepoCommitsAuthor",
    "GetByOrgByRepoCommitsAuthorTypedDict",
    "GetByOrgByRepoCommitsBadRequestError",
    "GetByOrgByRepoCommitsBadRequestErrorTypedDict",
    "GetByOrgByRepoCommitsByShaAuthor",
    "GetByOrgByRepoCommitsByShaAuthorTypedDict",
    "GetByOrgByRepoCommitsByShaBadRequestError",
    "GetByOrgByRepoCommitsByShaBadRequestErrorTypedDict",
    "GetByOrgByRepoCommitsByShaCommitter",
    "GetByOrgByRepoCommitsByShaCommitterTypedDict",
    "GetByOrgByRepoCommitsByShaConflictError",
    "GetByOrgByRepoCommitsByShaConflictErrorTypedDict",
    "GetByOrgByRepoCommitsByShaForbiddenError",
    "GetByOrgByRepoCommitsByShaForbiddenErrorTypedDict",
    "GetByOrgByRepoCommitsByShaInternalServerErrorError",
    "GetByOrgByRepoCommitsByShaInternalServerErrorErrorTypedDict",
    "GetByOrgByRepoCommitsByShaNotAcceptableError",
    "GetByOrgByRepoCommitsByShaNotAcceptableErrorTypedDict",
    "GetByOrgByRepoCommitsByShaNotFoundError",
    "GetByOrgByRepoCommitsByShaNotFoundErrorTypedDict",
    "GetByOrgByRepoCommitsByShaRequest",
    "GetByOrgByRepoCommitsByShaRequestTypedDict",
    "GetByOrgByRepoCommitsByShaResponse",
    "GetByOrgByRepoCommitsByShaResponseTypedDict",
    "GetByOrgByRepoCommitsByShaUnauthorizedError",
    "GetByOrgByRepoCommitsByShaUnauthorizedErrorTypedDict",
    "GetByOrgByRepoCommitsCommitter",
    "GetByOrgByRepoCommitsCommitterTypedDict",
    "GetByOrgByRepoCommitsConflictError",
    "GetByOrgByRepoCommitsConflictErrorTypedDict",
    "GetByOrgByRepoCommitsForbiddenError",
    "GetByOrgByRepoCommitsForbiddenErrorTypedDict",
    "GetByOrgByRepoCommitsInternalServerErrorError",
    "GetByOrgByRepoCommitsInternalServerErrorErrorTypedDict",
    "GetByOrgByRepoCommitsNotAcceptableError",
    "GetByOrgByRepoCommitsNotAcceptableErrorTypedDict",
    "GetByOrgByRepoCommitsNotFoundError",
    "GetByOrgByRepoCommitsNotFoundErrorTypedDict",
    "GetByOrgByRepoCommitsRequest",
    "GetByOrgByRepoCommitsRequestTypedDict",
    "GetByOrgByRepoCommitsResponse",
    "GetByOrgByRepoCommitsResponseBody",
    "GetByOrgByRepoCommitsResponseBodyTypedDict",
    "GetByOrgByRepoCommitsResponseTypedDict",
    "GetByOrgByRepoCommitsUnauthorizedError",
    "GetByOrgByRepoCommitsUnauthorizedErrorTypedDict",
    "GetByOrgByRepoConflictError",
    "GetByOrgByRepoConflictErrorTypedDict",
    "GetByOrgByRepoContentBadRequestError",
    "GetByOrgByRepoContentBadRequestErrorTypedDict",
    "GetByOrgByRepoContentConflictError",
    "GetByOrgByRepoContentConflictErrorTypedDict",
    "GetByOrgByRepoContentForbiddenError",
    "GetByOrgByRepoContentForbiddenErrorTypedDict",
    "GetByOrgByRepoContentInternalServerErrorError",
    "GetByOrgByRepoContentInternalServerErrorErrorTypedDict",
    "GetByOrgByRepoContentNotAcceptableError",
    "GetByOrgByRepoContentNotAcceptableErrorTypedDict",
    "GetByOrgByRepoContentNotFoundError",
    "GetByOrgByRepoContentNotFoundErrorTypedDict",
    "GetByOrgByRepoContentRequest",
    "GetByOrgByRepoContentRequestTypedDict",
    "GetByOrgByRepoContentResponse",
    "GetByOrgByRepoContentResponseBody",
    "GetByOrgByRepoContentResponseBodyTypedDict",
    "GetByOrgByRepoContentResponseTypedDict",
    "GetByOrgByRepoContentUnauthorizedError",
    "GetByOrgByRepoContentUnauthorizedErrorTypedDict",
    "GetByOrgByRepoDiffBadRequestError",
    "GetByOrgByRepoDiffBadRequestErrorTypedDict",
    "GetByOrgByRepoDiffConflictError",
    "GetByOrgByRepoDiffConflictErrorTypedDict",
    "GetByOrgByRepoDiffFile",
    "GetByOrgByRepoDiffFileTypedDict",
    "GetByOrgByRepoDiffForbiddenError",
    "GetByOrgByRepoDiffForbiddenErrorTypedDict",
    "GetByOrgByRepoDiffInternalServerErrorError",
    "GetByOrgByRepoDiffInternalServerErrorErrorTypedDict",
    "GetByOrgByRepoDiffNotAcceptableError",
    "GetByOrgByRepoDiffNotAcceptableErrorTypedDict",
    "GetByOrgByRepoDiffNotFoundError",
    "GetByOrgByRepoDiffNotFoundErrorTypedDict",
    "GetByOrgByRepoDiffRequest",
    "GetByOrgByRepoDiffRequestTypedDict",
    "GetByOrgByRepoDiffResponse",
    "GetByOrgByRepoDiffResponseBody",
    "GetByOrgByRepoDiffResponseBodyTypedDict",
    "GetByOrgByRepoDiffResponseTypedDict",
    "GetByOrgByRepoDiffStats",
    "GetByOrgByRepoDiffStatsTypedDict",
    "GetByOrgByRepoDiffUnauthorizedError",
    "GetByOrgByRepoDiffUnauthorizedErrorTypedDict",
    "GetByOrgByRepoForbiddenError",
    "GetByOrgByRepoForbiddenErrorTypedDict",
    "GetByOrgByRepoInternalServerErrorError",
    "GetByOrgByRepoInternalServerErrorErrorTypedDict",
    "GetByOrgByRepoNotAcceptableError",
    "GetByOrgByRepoNotAcceptableErrorTypedDict",
    "GetByOrgByRepoNotFoundError",
    "GetByOrgByRepoNotFoundErrorTypedDict",
    "GetByOrgByRepoRequest",
    "GetByOrgByRepoRequestTypedDict",
    "GetByOrgByRepoResolutionStrategy",
    "GetByOrgByRepoResponse",
    "GetByOrgByRepoResponseTypedDict",
    "GetByOrgByRepoSyncBadRequestError",
    "GetByOrgByRepoSyncBadRequestErrorTypedDict",
    "GetByOrgByRepoSyncConflictError",
    "GetByOrgByRepoSyncConflictErrorTypedDict",
    "GetByOrgByRepoSyncForbiddenError",
    "GetByOrgByRepoSyncForbiddenErrorTypedDict",
    "GetByOrgByRepoSyncInternalServerErrorError",
    "GetByOrgByRepoSyncInternalServerErrorErrorTypedDict",
    "GetByOrgByRepoSyncNotAcceptableError",
    "GetByOrgByRepoSyncNotAcceptableErrorTypedDict",
    "GetByOrgByRepoSyncNotFoundError",
    "GetByOrgByRepoSyncNotFoundErrorTypedDict",
    "GetByOrgByRepoSyncRequest",
    "GetByOrgByRepoSyncRequestTypedDict",
    "GetByOrgByRepoSyncResponse",
    "GetByOrgByRepoSyncResponseTypedDict",
    "GetByOrgByRepoSyncUnauthorizedError",
    "GetByOrgByRepoSyncUnauthorizedErrorTypedDict",
    "GetByOrgByRepoUnauthorizedError",
    "GetByOrgByRepoUnauthorizedErrorTypedDict",
    "GetByOrgByRepoUpstream",
    "GetByOrgByRepoUpstreamTypedDict",
    "GetByOrgByRepoWebhooksBadRequestError",
    "GetByOrgByRepoWebhooksBadRequestErrorTypedDict",
    "GetByOrgByRepoWebhooksConflictError",
    "GetByOrgByRepoWebhooksConflictErrorTypedDict",
    "GetByOrgByRepoWebhooksEvent",
    "GetByOrgByRepoWebhooksForbiddenError",
    "GetByOrgByRepoWebhooksForbiddenErrorTypedDict",
    "GetByOrgByRepoWebhooksInternalServerErrorError",
    "GetByOrgByRepoWebhooksInternalServerErrorErrorTypedDict",
    "GetByOrgByRepoWebhooksNotAcceptableError",
    "GetByOrgByRepoWebhooksNotAcceptableErrorTypedDict",
    "GetByOrgByRepoWebhooksNotFoundError",
    "GetByOrgByRepoWebhooksNotFoundErrorTypedDict",
    "GetByOrgByRepoWebhooksRequest",
    "GetByOrgByRepoWebhooksRequestTypedDict",
    "GetByOrgByRepoWebhooksResponse",
    "GetByOrgByRepoWebhooksResponseTypedDict",
    "GetByOrgByRepoWebhooksUnauthorizedError",
    "GetByOrgByRepoWebhooksUnauthorizedErrorTypedDict",
    "GetByOrgConflictError",
    "GetByOrgConflictErrorTypedDict",
    "GetByOrgForbiddenError",
    "GetByOrgForbiddenErrorTypedDict",
    "GetByOrgInternalServerErrorError",
    "GetByOrgInternalServerErrorErrorTypedDict",
    "GetByOrgNotAcceptableError",
    "GetByOrgNotAcceptableErrorTypedDict",
    "GetByOrgNotFoundError",
    "GetByOrgNotFoundErrorTypedDict",
    "GetByOrgReposAutosync",
    "GetByOrgReposAutosyncTypedDict",
    "GetByOrgReposBadRequestError",
    "GetByOrgReposBadRequestErrorTypedDict",
    "GetByOrgReposConflictError",
    "GetByOrgReposConflictErrorTypedDict",
    "GetByOrgReposForbiddenError",
    "GetByOrgReposForbiddenErrorTypedDict",
    "GetByOrgReposInternalServerErrorError",
    "GetByOrgReposInternalServerErrorErrorTypedDict",
    "GetByOrgReposNotAcceptableError",
    "GetByOrgReposNotAcceptableErrorTypedDict",
    "GetByOrgReposNotFoundError",
    "GetByOrgReposNotFoundErrorTypedDict",
    "GetByOrgReposRequest",
    "GetByOrgReposRequestTypedDict",
    "GetByOrgReposResolutionStrategy",
    "GetByOrgReposResponse",
    "GetByOrgReposResponseBody",
    "GetByOrgReposResponseBodyTypedDict",
    "GetByOrgReposResponseTypedDict",
    "GetByOrgReposUnauthorizedError",
    "GetByOrgReposUnauthorizedErrorTypedDict",
    "GetByOrgReposUpstream",
    "GetByOrgReposUpstreamTypedDict",
    "GetByOrgRequest",
    "GetByOrgRequestTypedDict",
    "GetByOrgResponse",
    "GetByOrgResponseTypedDict",
    "GetByOrgUnauthorizedError",
    "GetByOrgUnauthorizedErrorTypedDict",
    "PatchByOrgByRepoAutosyncPollRequest",
    "PatchByOrgByRepoAutosyncPollRequestTypedDict",
    "PatchByOrgByRepoAutosyncResponse",
    "PatchByOrgByRepoAutosyncResponseTypedDict",
    "PatchByOrgByRepoAutosyncUnion",
    "PatchByOrgByRepoAutosyncUnionTypedDict",
    "PatchByOrgByRepoBadRequestError",
    "PatchByOrgByRepoBadRequestErrorTypedDict",
    "PatchByOrgByRepoConflictError",
    "PatchByOrgByRepoConflictErrorTypedDict",
    "PatchByOrgByRepoForbiddenError",
    "PatchByOrgByRepoForbiddenErrorTypedDict",
    "PatchByOrgByRepoInternalServerErrorError",
    "PatchByOrgByRepoInternalServerErrorErrorTypedDict",
    "PatchByOrgByRepoNotAcceptableError",
    "PatchByOrgByRepoNotAcceptableErrorTypedDict",
    "PatchByOrgByRepoNotFoundError",
    "PatchByOrgByRepoNotFoundErrorTypedDict",
    "PatchByOrgByRepoRequest",
    "PatchByOrgByRepoRequestBody",
    "PatchByOrgByRepoRequestBodyTypedDict",
    "PatchByOrgByRepoRequestTypedDict",
    "PatchByOrgByRepoResolutionStrategyRequest",
    "PatchByOrgByRepoResolutionStrategyResponse",
    "PatchByOrgByRepoResponse",
    "PatchByOrgByRepoResponseTypedDict",
    "PatchByOrgByRepoUnauthorizedError",
    "PatchByOrgByRepoUnauthorizedErrorTypedDict",
    "PatchByOrgByRepoUpstreamRequest",
    "PatchByOrgByRepoUpstreamRequestTypedDict",
    "PatchByOrgByRepoUpstreamResponse",
    "PatchByOrgByRepoUpstreamResponseTypedDict",
    "Period",
    "PostByOrgAPIKeysBadRequestError",
    "PostByOrgAPIKeysBadRequestErrorTypedDict",
    "PostByOrgAPIKeysConflictError",
    "PostByOrgAPIKeysConflictErrorTypedDict",
    "PostByOrgAPIKeysForbiddenError",
    "PostByOrgAPIKeysForbiddenErrorTypedDict",
    "PostByOrgAPIKeysInternalServerErrorError",
    "PostByOrgAPIKeysInternalServerErrorErrorTypedDict",
    "PostByOrgAPIKeysNotAcceptableError",
    "PostByOrgAPIKeysNotAcceptableErrorTypedDict",
    "PostByOrgAPIKeysNotFoundError",
    "PostByOrgAPIKeysNotFoundErrorTypedDict",
    "PostByOrgAPIKeysRequest",
    "PostByOrgAPIKeysRequestBody",
    "PostByOrgAPIKeysRequestBodyTypedDict",
    "PostByOrgAPIKeysRequestTypedDict",
    "PostByOrgAPIKeysResponse",
    "PostByOrgAPIKeysResponseTypedDict",
    "PostByOrgAPIKeysUnauthorizedError",
    "PostByOrgAPIKeysUnauthorizedErrorTypedDict",
    "PostByOrgByRepoAnalyticsRefreshAnalytics",
    "PostByOrgByRepoAnalyticsRefreshAnalyticsTypedDict",
    "PostByOrgByRepoAnalyticsRefreshBadRequestError",
    "PostByOrgByRepoAnalyticsRefreshBadRequestErrorTypedDict",
    "PostByOrgByRepoAnalyticsRefreshConflictError",
    "PostByOrgByRepoAnalyticsRefreshConflictErrorTypedDict",
    "PostByOrgByRepoAnalyticsRefreshContributors",
    "PostByOrgByRepoAnalyticsRefreshContributorsTypedDict",
    "PostByOrgByRepoAnalyticsRefreshForbiddenError",
    "PostByOrgByRepoAnalyticsRefreshForbiddenErrorTypedDict",
    "PostByOrgByRepoAnalyticsRefreshHistory",
    "PostByOrgByRepoAnalyticsRefreshHistoryTypedDict",
    "PostByOrgByRepoAnalyticsRefreshInternalServerErrorError",
    "PostByOrgByRepoAnalyticsRefreshInternalServerErrorErrorTypedDict",
    "PostByOrgByRepoAnalyticsRefreshMeta",
    "PostByOrgByRepoAnalyticsRefreshMetaTypedDict",
    "PostByOrgByRepoAnalyticsRefreshNotAcceptableError",
    "PostByOrgByRepoAnalyticsRefreshNotAcceptableErrorTypedDict",
    "PostByOrgByRepoAnalyticsRefreshNotFoundError",
    "PostByOrgByRepoAnalyticsRefreshNotFoundErrorTypedDict",
    "PostByOrgByRepoAnalyticsRefreshRequest",
    "PostByOrgByRepoAnalyticsRefreshRequestTypedDict",
    "PostByOrgByRepoAnalyticsRefreshResponse",
    "PostByOrgByRepoAnalyticsRefreshResponseTypedDict",
    "PostByOrgByRepoAnalyticsRefreshStatus",
    "PostByOrgByRepoAnalyticsRefreshSummary",
    "PostByOrgByRepoAnalyticsRefreshSummaryTypedDict",
    "PostByOrgByRepoAnalyticsRefreshUnauthorizedError",
    "PostByOrgByRepoAnalyticsRefreshUnauthorizedErrorTypedDict",
    "PostByOrgByRepoBranchesBadRequestError",
    "PostByOrgByRepoBranchesBadRequestErrorTypedDict",
    "PostByOrgByRepoBranchesConflictError",
    "PostByOrgByRepoBranchesConflictErrorTypedDict",
    "PostByOrgByRepoBranchesForbiddenError",
    "PostByOrgByRepoBranchesForbiddenErrorTypedDict",
    "PostByOrgByRepoBranchesInternalServerErrorError",
    "PostByOrgByRepoBranchesInternalServerErrorErrorTypedDict",
    "PostByOrgByRepoBranchesNotAcceptableError",
    "PostByOrgByRepoBranchesNotAcceptableErrorTypedDict",
    "PostByOrgByRepoBranchesNotFoundError",
    "PostByOrgByRepoBranchesNotFoundErrorTypedDict",
    "PostByOrgByRepoBranchesRequest",
    "PostByOrgByRepoBranchesRequestBody",
    "PostByOrgByRepoBranchesRequestBodyTypedDict",
    "PostByOrgByRepoBranchesRequestTypedDict",
    "PostByOrgByRepoBranchesResponse",
    "PostByOrgByRepoBranchesResponseTypedDict",
    "PostByOrgByRepoBranchesUnauthorizedError",
    "PostByOrgByRepoBranchesUnauthorizedErrorTypedDict",
    "PostByOrgByRepoCommitsAuthor",
    "PostByOrgByRepoCommitsAuthorTypedDict",
    "PostByOrgByRepoCommitsBadRequestError",
    "PostByOrgByRepoCommitsBadRequestErrorTypedDict",
    "PostByOrgByRepoCommitsConflictError",
    "PostByOrgByRepoCommitsConflictErrorTypedDict",
    "PostByOrgByRepoCommitsForbiddenError",
    "PostByOrgByRepoCommitsForbiddenErrorTypedDict",
    "PostByOrgByRepoCommitsInternalServerErrorError",
    "PostByOrgByRepoCommitsInternalServerErrorErrorTypedDict",
    "PostByOrgByRepoCommitsNotAcceptableError",
    "PostByOrgByRepoCommitsNotAcceptableErrorTypedDict",
    "PostByOrgByRepoCommitsNotFoundError",
    "PostByOrgByRepoCommitsNotFoundErrorTypedDict",
    "PostByOrgByRepoCommitsRequest",
    "PostByOrgByRepoCommitsRequestBody",
    "PostByOrgByRepoCommitsRequestBodyTypedDict",
    "PostByOrgByRepoCommitsRequestTypedDict",
    "PostByOrgByRepoCommitsResponse",
    "PostByOrgByRepoCommitsResponseTypedDict",
    "PostByOrgByRepoCommitsUnauthorizedError",
    "PostByOrgByRepoCommitsUnauthorizedErrorTypedDict",
    "PostByOrgByRepoSyncBadRequestError",
    "PostByOrgByRepoSyncBadRequestErrorTypedDict",
    "PostByOrgByRepoSyncConflictError",
    "PostByOrgByRepoSyncConflictErrorTypedDict",
    "PostByOrgByRepoSyncForbiddenError",
    "PostByOrgByRepoSyncForbiddenErrorTypedDict",
    "PostByOrgByRepoSyncInternalServerErrorError",
    "PostByOrgByRepoSyncInternalServerErrorErrorTypedDict",
    "PostByOrgByRepoSyncNotAcceptableError",
    "PostByOrgByRepoSyncNotAcceptableErrorTypedDict",
    "PostByOrgByRepoSyncNotFoundError",
    "PostByOrgByRepoSyncNotFoundErrorTypedDict",
    "PostByOrgByRepoSyncRequest",
    "PostByOrgByRepoSyncRequestTypedDict",
    "PostByOrgByRepoSyncResponse",
    "PostByOrgByRepoSyncResponseTypedDict",
    "PostByOrgByRepoSyncUnauthorizedError",
    "PostByOrgByRepoSyncUnauthorizedErrorTypedDict",
    "PostByOrgByRepoWebhooksBadRequestError",
    "PostByOrgByRepoWebhooksBadRequestErrorTypedDict",
    "PostByOrgByRepoWebhooksConflictError",
    "PostByOrgByRepoWebhooksConflictErrorTypedDict",
    "PostByOrgByRepoWebhooksEventResponse",
    "PostByOrgByRepoWebhooksForbiddenError",
    "PostByOrgByRepoWebhooksForbiddenErrorTypedDict",
    "PostByOrgByRepoWebhooksInternalServerErrorError",
    "PostByOrgByRepoWebhooksInternalServerErrorErrorTypedDict",
    "PostByOrgByRepoWebhooksNotAcceptableError",
    "PostByOrgByRepoWebhooksNotAcceptableErrorTypedDict",
    "PostByOrgByRepoWebhooksNotFoundError",
    "PostByOrgByRepoWebhooksNotFoundErrorTypedDict",
    "PostByOrgByRepoWebhooksRequest",
    "PostByOrgByRepoWebhooksRequestBody",
    "PostByOrgByRepoWebhooksRequestBodyTypedDict",
    "PostByOrgByRepoWebhooksRequestTypedDict",
    "PostByOrgByRepoWebhooksResponse",
    "PostByOrgByRepoWebhooksResponseTypedDict",
    "PostByOrgByRepoWebhooksUnauthorizedError",
    "PostByOrgByRepoWebhooksUnauthorizedErrorTypedDict",
    "PostByOrgReposAutosyncPollRequest",
    "PostByOrgReposAutosyncPollRequestTypedDict",
    "PostByOrgReposAutosyncResponse",
    "PostByOrgReposAutosyncResponseTypedDict",
    "PostByOrgReposAutosyncUnion",
    "PostByOrgReposAutosyncUnionTypedDict",
    "PostByOrgReposBadRequestError",
    "PostByOrgReposBadRequestErrorTypedDict",
    "PostByOrgReposConflictError",
    "PostByOrgReposConflictErrorTypedDict",
    "PostByOrgReposForbiddenError",
    "PostByOrgReposForbiddenErrorTypedDict",
    "PostByOrgReposInternalServerErrorError",
    "PostByOrgReposInternalServerErrorErrorTypedDict",
    "PostByOrgReposNotAcceptableError",
    "PostByOrgReposNotAcceptableErrorTypedDict",
    "PostByOrgReposNotFoundError",
    "PostByOrgReposNotFoundErrorTypedDict",
    "PostByOrgReposRequest",
    "PostByOrgReposRequestBody",
    "PostByOrgReposRequestBodyTypedDict",
    "PostByOrgReposRequestTypedDict",
    "PostByOrgReposResolutionStrategyRequest",
    "PostByOrgReposResolutionStrategyResponse",
    "PostByOrgReposResponse",
    "PostByOrgReposResponseTypedDict",
    "PostByOrgReposUnauthorizedError",
    "PostByOrgReposUnauthorizedErrorTypedDict",
    "PostByOrgReposUpstreamRequest",
    "PostByOrgReposUpstreamRequestTypedDict",
    "PostByOrgReposUpstreamResponse",
    "PostByOrgReposUpstreamResponseTypedDict",
    "Repo",
    "RepoTypedDict",
    "Scope",
    "Security",
    "SecurityTypedDict",
    "Status",
    "StatusError",
    "StatusErrorTypedDict",
    "StatusOk",
    "StatusOkTypedDict",
    "StatusTypedDict",
    "SymlinkBase64",
    "SymlinkBase64TypedDict",
    "Webhook",
    "WebhookTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "DeleteByOrgAPIKeysByIDBadRequestError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDBadRequestErrorTypedDict": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDConflictError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDConflictErrorTypedDict": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDForbiddenError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDForbiddenErrorTypedDict": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDInternalServerErrorError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDInternalServerErrorErrorTypedDict": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDNotAcceptableError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDNotAcceptableErrorTypedDict": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDNotFoundError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDNotFoundErrorTypedDict": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDRequest": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDRequestTypedDict": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDResponse": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDResponseTypedDict": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDUnauthorizedError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDUnauthorizedErrorTypedDict": ".deletebyorgapikeysbyidop",
    "DeleteByOrgByRepoBranchesByBranchBadRequestError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchBadRequestErrorTypedDict": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchConflictError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchConflictErrorTypedDict": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchForbiddenError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchForbiddenErrorTypedDict": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchInternalServerErrorError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchInternalServerErrorErrorTypedDict": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchNotAcceptableError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchNotAcceptableErrorTypedDict": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchNotFoundError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchNotFoundErrorTypedDict": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchRequest": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchRequestTypedDict": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchResponse": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchResponseTypedDict": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchUnauthorizedError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchUnauthorizedErrorTypedDict": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBadRequestError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoBadRequestErrorTypedDict": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoConflictError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoConflictErrorTypedDict": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoForbiddenError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoForbiddenErrorTypedDict": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoInternalServerErrorError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoInternalServerErrorErrorTypedDict": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoNotAcceptableError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoNotAcceptableErrorTypedDict": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoNotFoundError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoNotFoundErrorTypedDict": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoRequest": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoRequestTypedDict": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoResponse": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoResponseTypedDict": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoUnauthorizedError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoUnauthorizedErrorTypedDict": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoWebhooksByWebhookIDBadRequestError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDBadRequestErrorTypedDict": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDConflictError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDConflictErrorTypedDict": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDForbiddenError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDForbiddenErrorTypedDict": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDInternalServerErrorError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDInternalServerErrorErrorTypedDict": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableErrorTypedDict": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotFoundError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotFoundErrorTypedDict": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDRequest": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDRequestTypedDict": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDResponse": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDResponseTypedDict": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedErrorTypedDict": ".deletebyorgbyrepowebhooksbywebhookidop",
    "APIKey": ".getbyorgapikeysop",
    "APIKeyTypedDict": ".getbyorgapikeysop",
    "GetByOrgAPIKeysBadRequestError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysBadRequestErrorTypedDict": ".getbyorgapikeysop",
    "GetByOrgAPIKeysConflictError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysConflictErrorTypedDict": ".getbyorgapikeysop",
    "GetByOrgAPIKeysForbiddenError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysForbiddenErrorTypedDict": ".getbyorgapikeysop",
    "GetByOrgAPIKeysInternalServerErrorError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysInternalServerErrorErrorTypedDict": ".getbyorgapikeysop",
    "GetByOrgAPIKeysNotAcceptableError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysNotAcceptableErrorTypedDict": ".getbyorgapikeysop",
    "GetByOrgAPIKeysNotFoundError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysNotFoundErrorTypedDict": ".getbyorgapikeysop",
    "GetByOrgAPIKeysRequest": ".getbyorgapikeysop",
    "GetByOrgAPIKeysRequestTypedDict": ".getbyorgapikeysop",
    "GetByOrgAPIKeysResponse": ".getbyorgapikeysop",
    "GetByOrgAPIKeysResponseTypedDict": ".getbyorgapikeysop",
    "GetByOrgAPIKeysUnauthorizedError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysUnauthorizedErrorTypedDict": ".getbyorgapikeysop",
    "Attribution": ".getbyorgbyrepoagentblameop",
    "AttributionTypedDict": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameBadRequestError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameBadRequestErrorTypedDict": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameConflictError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameConflictErrorTypedDict": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameForbiddenError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameForbiddenErrorTypedDict": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameInternalServerErrorError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameInternalServerErrorErrorTypedDict": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameNotAcceptableError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameNotAcceptableErrorTypedDict": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameNotFoundError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameNotFoundErrorTypedDict": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameRequest": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameRequestTypedDict": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameResponse": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameResponseTypedDict": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameStats": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameStatsTypedDict": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameUnauthorizedError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameUnauthorizedErrorTypedDict": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAnalyticsAnalytics": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsAnalyticsTypedDict": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsBadRequestError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsBadRequestErrorTypedDict": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsConflictError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsConflictErrorTypedDict": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsContributors": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsContributorsTypedDict": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsForbiddenError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsForbiddenErrorTypedDict": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsHistory": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsHistoryTypedDict": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsInternalServerErrorError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsInternalServerErrorErrorTypedDict": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsMeta": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsMetaTypedDict": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsNotAcceptableError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsNotAcceptableErrorTypedDict": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsNotFoundError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsNotFoundErrorTypedDict": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsRequest": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsRequestTypedDict": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsResponse": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsResponseTypedDict": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsStatus": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsSummary": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsSummaryTypedDict": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsUnauthorizedError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsUnauthorizedErrorTypedDict": ".getbyorgbyrepoanalyticsop",
    "Period": ".getbyorgbyrepoanalyticsop",
    "Branch": ".getbyorgbyrepobranchesop",
    "BranchTypedDict": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesBadRequestError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesBadRequestErrorTypedDict": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesConflictError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesConflictErrorTypedDict": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesForbiddenError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesForbiddenErrorTypedDict": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesInternalServerErrorError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesInternalServerErrorErrorTypedDict": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesNotAcceptableError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesNotAcceptableErrorTypedDict": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesNotFoundError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesNotFoundErrorTypedDict": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesRequest": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesRequestTypedDict": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesResponse": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesResponseBody": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesResponseBodyTypedDict": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesResponseTypedDict": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesUnauthorizedError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesUnauthorizedErrorTypedDict": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoCommitsByShaAuthor": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaAuthorTypedDict": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaBadRequestError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaBadRequestErrorTypedDict": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaCommitter": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaCommitterTypedDict": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaConflictError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaConflictErrorTypedDict": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaForbiddenError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaForbiddenErrorTypedDict": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaInternalServerErrorError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaInternalServerErrorErrorTypedDict": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaNotAcceptableError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaNotAcceptableErrorTypedDict": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaNotFoundError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaNotFoundErrorTypedDict": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaRequest": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaRequestTypedDict": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaResponse": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaResponseTypedDict": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaUnauthorizedError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaUnauthorizedErrorTypedDict": ".getbyorgbyrepocommitsbyshaop",
    "Commit": ".getbyorgbyrepocommitsop",
    "CommitTypedDict": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsAuthor": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsAuthorTypedDict": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsBadRequestError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsBadRequestErrorTypedDict": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsCommitter": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsCommitterTypedDict": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsConflictError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsConflictErrorTypedDict": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsForbiddenError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsForbiddenErrorTypedDict": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsInternalServerErrorError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsInternalServerErrorErrorTypedDict": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsNotAcceptableError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsNotAcceptableErrorTypedDict": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsNotFoundError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsNotFoundErrorTypedDict": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsRequest": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsRequestTypedDict": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsResponse": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsResponseBody": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsResponseBodyTypedDict": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsResponseTypedDict": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsUnauthorizedError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsUnauthorizedErrorTypedDict": ".getbyorgbyrepocommitsop",
    "Dir": ".getbyorgbyrepocontentop",
    "DirTypedDict": ".getbyorgbyrepocontentop",
    "Entry": ".getbyorgbyrepocontentop",
    "EntryDir": ".getbyorgbyrepocontentop",
    "EntryDirTypedDict": ".getbyorgbyrepocontentop",
    "EntryFile": ".getbyorgbyrepocontentop",
    "EntryFileTypedDict": ".getbyorgbyrepocontentop",
    "EntrySymlink": ".getbyorgbyrepocontentop",
    "EntrySymlinkTypedDict": ".getbyorgbyrepocontentop",
    "EntryTypedDict": ".getbyorgbyrepocontentop",
    "FileBase64": ".getbyorgbyrepocontentop",
    "FileBase64TypedDict": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentBadRequestError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentBadRequestErrorTypedDict": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentConflictError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentConflictErrorTypedDict": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentForbiddenError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentForbiddenErrorTypedDict": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentInternalServerErrorError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentInternalServerErrorErrorTypedDict": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentNotAcceptableError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentNotAcceptableErrorTypedDict": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentNotFoundError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentNotFoundErrorTypedDict": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentRequest": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentRequestTypedDict": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentResponse": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentResponseBody": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentResponseBodyTypedDict": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentResponseTypedDict": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentUnauthorizedError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentUnauthorizedErrorTypedDict": ".getbyorgbyrepocontentop",
    "SymlinkBase64": ".getbyorgbyrepocontentop",
    "SymlinkBase64TypedDict": ".getbyorgbyrepocontentop",
    "FileStatus": ".getbyorgbyrepodiffop",
    "FilteredFile": ".getbyorgbyrepodiffop",
    "FilteredFileStatus": ".getbyorgbyrepodiffop",
    "FilteredFileTypedDict": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffBadRequestError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffBadRequestErrorTypedDict": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffConflictError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffConflictErrorTypedDict": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffFile": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffFileTypedDict": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffForbiddenError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffForbiddenErrorTypedDict": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffInternalServerErrorError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffInternalServerErrorErrorTypedDict": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffNotAcceptableError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffNotAcceptableErrorTypedDict": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffNotFoundError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffNotFoundErrorTypedDict": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffRequest": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffRequestTypedDict": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffResponse": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffResponseBody": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffResponseBodyTypedDict": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffResponseTypedDict": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffStats": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffStatsTypedDict": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffUnauthorizedError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffUnauthorizedErrorTypedDict": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoAutosync": ".getbyorgbyrepoop",
    "GetByOrgByRepoAutosyncTypedDict": ".getbyorgbyrepoop",
    "GetByOrgByRepoBadRequestError": ".getbyorgbyrepoop",
    "GetByOrgByRepoBadRequestErrorTypedDict": ".getbyorgbyrepoop",
    "GetByOrgByRepoConflictError": ".getbyorgbyrepoop",
    "GetByOrgByRepoConflictErrorTypedDict": ".getbyorgbyrepoop",
    "GetByOrgByRepoForbiddenError": ".getbyorgbyrepoop",
    "GetByOrgByRepoForbiddenErrorTypedDict": ".getbyorgbyrepoop",
    "GetByOrgByRepoInternalServerErrorError": ".getbyorgbyrepoop",
    "GetByOrgByRepoInternalServerErrorErrorTypedDict": ".getbyorgbyrepoop",
    "GetByOrgByRepoNotAcceptableError": ".getbyorgbyrepoop",
    "GetByOrgByRepoNotAcceptableErrorTypedDict": ".getbyorgbyrepoop",
    "GetByOrgByRepoNotFoundError": ".getbyorgbyrepoop",
    "GetByOrgByRepoNotFoundErrorTypedDict": ".getbyorgbyrepoop",
    "GetByOrgByRepoRequest": ".getbyorgbyrepoop",
    "GetByOrgByRepoRequestTypedDict": ".getbyorgbyrepoop",
    "GetByOrgByRepoResolutionStrategy": ".getbyorgbyrepoop",
    "GetByOrgByRepoResponse": ".getbyorgbyrepoop",
    "GetByOrgByRepoResponseTypedDict": ".getbyorgbyrepoop",
    "GetByOrgByRepoUnauthorizedError": ".getbyorgbyrepoop",
    "GetByOrgByRepoUnauthorizedErrorTypedDict": ".getbyorgbyrepoop",
    "GetByOrgByRepoUpstream": ".getbyorgbyrepoop",
    "GetByOrgByRepoUpstreamTypedDict": ".getbyorgbyrepoop",
    "GetByOrgByRepoSyncBadRequestError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncBadRequestErrorTypedDict": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncConflictError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncConflictErrorTypedDict": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncForbiddenError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncForbiddenErrorTypedDict": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncInternalServerErrorError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncInternalServerErrorErrorTypedDict": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncNotAcceptableError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncNotAcceptableErrorTypedDict": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncNotFoundError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncNotFoundErrorTypedDict": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncRequest": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncRequestTypedDict": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncResponse": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncResponseTypedDict": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncUnauthorizedError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncUnauthorizedErrorTypedDict": ".getbyorgbyreposyncop",
    "Status": ".getbyorgbyreposyncop",
    "StatusError": ".getbyorgbyreposyncop",
    "StatusErrorTypedDict": ".getbyorgbyreposyncop",
    "StatusOk": ".getbyorgbyreposyncop",
    "StatusOkTypedDict": ".getbyorgbyreposyncop",
    "StatusTypedDict": ".getbyorgbyreposyncop",
    "GetByOrgByRepoWebhooksBadRequestError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksBadRequestErrorTypedDict": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksConflictError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksConflictErrorTypedDict": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksEvent": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksForbiddenError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksForbiddenErrorTypedDict": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksInternalServerErrorError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksInternalServerErrorErrorTypedDict": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksNotAcceptableError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksNotAcceptableErrorTypedDict": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksNotFoundError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksNotFoundErrorTypedDict": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksRequest": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksRequestTypedDict": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksResponse": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksResponseTypedDict": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksUnauthorizedError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksUnauthorizedErrorTypedDict": ".getbyorgbyrepowebhooksop",
    "Webhook": ".getbyorgbyrepowebhooksop",
    "WebhookTypedDict": ".getbyorgbyrepowebhooksop",
    "GetByOrgBadRequestError": ".getbyorgop",
    "GetByOrgBadRequestErrorTypedDict": ".getbyorgop",
    "GetByOrgConflictError": ".getbyorgop",
    "GetByOrgConflictErrorTypedDict": ".getbyorgop",
    "GetByOrgForbiddenError": ".getbyorgop",
    "GetByOrgForbiddenErrorTypedDict": ".getbyorgop",
    "GetByOrgInternalServerErrorError": ".getbyorgop",
    "GetByOrgInternalServerErrorErrorTypedDict": ".getbyorgop",
    "GetByOrgNotAcceptableError": ".getbyorgop",
    "GetByOrgNotAcceptableErrorTypedDict": ".getbyorgop",
    "GetByOrgNotFoundError": ".getbyorgop",
    "GetByOrgNotFoundErrorTypedDict": ".getbyorgop",
    "GetByOrgRequest": ".getbyorgop",
    "GetByOrgRequestTypedDict": ".getbyorgop",
    "GetByOrgResponse": ".getbyorgop",
    "GetByOrgResponseTypedDict": ".getbyorgop",
    "GetByOrgUnauthorizedError": ".getbyorgop",
    "GetByOrgUnauthorizedErrorTypedDict": ".getbyorgop",
    "GetByOrgReposAutosync": ".getbyorgreposop",
    "GetByOrgReposAutosyncTypedDict": ".getbyorgreposop",
    "GetByOrgReposBadRequestError": ".getbyorgreposop",
    "GetByOrgReposBadRequestErrorTypedDict": ".getbyorgreposop",
    "GetByOrgReposConflictError": ".getbyorgreposop",
    "GetByOrgReposConflictErrorTypedDict": ".getbyorgreposop",
    "GetByOrgReposForbiddenError": ".getbyorgreposop",
    "GetByOrgReposForbiddenErrorTypedDict": ".getbyorgreposop",
    "GetByOrgReposInternalServerErrorError": ".getbyorgreposop",
    "GetByOrgReposInternalServerErrorErrorTypedDict": ".getbyorgreposop",
    "GetByOrgReposNotAcceptableError": ".getbyorgreposop",
    "GetByOrgReposNotAcceptableErrorTypedDict": ".getbyorgreposop",
    "GetByOrgReposNotFoundError": ".getbyorgreposop",
    "GetByOrgReposNotFoundErrorTypedDict": ".getbyorgreposop",
    "GetByOrgReposRequest": ".getbyorgreposop",
    "GetByOrgReposRequestTypedDict": ".getbyorgreposop",
    "GetByOrgReposResolutionStrategy": ".getbyorgreposop",
    "GetByOrgReposResponse": ".getbyorgreposop",
    "GetByOrgReposResponseBody": ".getbyorgreposop",
    "GetByOrgReposResponseBodyTypedDict": ".getbyorgreposop",
    "GetByOrgReposResponseTypedDict": ".getbyorgreposop",
    "GetByOrgReposUnauthorizedError": ".getbyorgreposop",
    "GetByOrgReposUnauthorizedErrorTypedDict": ".getbyorgreposop",
    "GetByOrgReposUpstream": ".getbyorgreposop",
    "GetByOrgReposUpstreamTypedDict": ".getbyorgreposop",
    "Repo": ".getbyorgreposop",
    "RepoTypedDict": ".getbyorgreposop",
    "PatchByOrgByRepoAutosyncPollRequest": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoAutosyncPollRequestTypedDict": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoAutosyncResponse": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoAutosyncResponseTypedDict": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoAutosyncUnion": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoAutosyncUnionTypedDict": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoBadRequestError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoBadRequestErrorTypedDict": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoConflictError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoConflictErrorTypedDict": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoForbiddenError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoForbiddenErrorTypedDict": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoInternalServerErrorError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoInternalServerErrorErrorTypedDict": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoNotAcceptableError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoNotAcceptableErrorTypedDict": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoNotFoundError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoNotFoundErrorTypedDict": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoRequest": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoRequestBody": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoRequestBodyTypedDict": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoRequestTypedDict": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoResolutionStrategyRequest": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoResolutionStrategyResponse": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoResponse": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoResponseTypedDict": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoUnauthorizedError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoUnauthorizedErrorTypedDict": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoUpstreamRequest": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoUpstreamRequestTypedDict": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoUpstreamResponse": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoUpstreamResponseTypedDict": ".patchbyorgbyrepoop",
    "PostByOrgAPIKeysBadRequestError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysBadRequestErrorTypedDict": ".postbyorgapikeysop",
    "PostByOrgAPIKeysConflictError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysConflictErrorTypedDict": ".postbyorgapikeysop",
    "PostByOrgAPIKeysForbiddenError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysForbiddenErrorTypedDict": ".postbyorgapikeysop",
    "PostByOrgAPIKeysInternalServerErrorError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysInternalServerErrorErrorTypedDict": ".postbyorgapikeysop",
    "PostByOrgAPIKeysNotAcceptableError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysNotAcceptableErrorTypedDict": ".postbyorgapikeysop",
    "PostByOrgAPIKeysNotFoundError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysNotFoundErrorTypedDict": ".postbyorgapikeysop",
    "PostByOrgAPIKeysRequest": ".postbyorgapikeysop",
    "PostByOrgAPIKeysRequestBody": ".postbyorgapikeysop",
    "PostByOrgAPIKeysRequestBodyTypedDict": ".postbyorgapikeysop",
    "PostByOrgAPIKeysRequestTypedDict": ".postbyorgapikeysop",
    "PostByOrgAPIKeysResponse": ".postbyorgapikeysop",
    "PostByOrgAPIKeysResponseTypedDict": ".postbyorgapikeysop",
    "PostByOrgAPIKeysUnauthorizedError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysUnauthorizedErrorTypedDict": ".postbyorgapikeysop",
    "Scope": ".postbyorgapikeysop",
    "PostByOrgByRepoAnalyticsRefreshAnalytics": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshAnalyticsTypedDict": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshBadRequestError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshBadRequestErrorTypedDict": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshConflictError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshConflictErrorTypedDict": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshContributors": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshContributorsTypedDict": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshForbiddenError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshForbiddenErrorTypedDict": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshHistory": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshHistoryTypedDict": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshInternalServerErrorError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshInternalServerErrorErrorTypedDict": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshMeta": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshMetaTypedDict": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshNotAcceptableError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshNotAcceptableErrorTypedDict": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshNotFoundError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshNotFoundErrorTypedDict": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshRequest": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshRequestTypedDict": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshResponse": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshResponseTypedDict": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshStatus": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshSummary": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshSummaryTypedDict": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshUnauthorizedError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshUnauthorizedErrorTypedDict": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoBranchesBadRequestError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesBadRequestErrorTypedDict": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesConflictError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesConflictErrorTypedDict": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesForbiddenError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesForbiddenErrorTypedDict": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesInternalServerErrorError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesInternalServerErrorErrorTypedDict": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesNotAcceptableError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesNotAcceptableErrorTypedDict": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesNotFoundError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesNotFoundErrorTypedDict": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesRequest": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesRequestBody": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesRequestBodyTypedDict": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesRequestTypedDict": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesResponse": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesResponseTypedDict": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesUnauthorizedError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesUnauthorizedErrorTypedDict": ".postbyorgbyrepobranchesop",
    "Encoding": ".postbyorgbyrepocommitsop",
    "File": ".postbyorgbyrepocommitsop",
    "FileDelete": ".postbyorgbyrepocommitsop",
    "FileDeleteTypedDict": ".postbyorgbyrepocommitsop",
    "FileTypedDict": ".postbyorgbyrepocommitsop",
    "FileUpsert": ".postbyorgbyrepocommitsop",
    "FileUpsertTypedDict": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsAuthor": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsAuthorTypedDict": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsBadRequestError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsBadRequestErrorTypedDict": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsConflictError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsConflictErrorTypedDict": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsForbiddenError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsForbiddenErrorTypedDict": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsInternalServerErrorError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsInternalServerErrorErrorTypedDict": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsNotAcceptableError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsNotAcceptableErrorTypedDict": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsNotFoundError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsNotFoundErrorTypedDict": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsRequest": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsRequestBody": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsRequestBodyTypedDict": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsRequestTypedDict": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsResponse": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsResponseTypedDict": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsUnauthorizedError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsUnauthorizedErrorTypedDict": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoSyncBadRequestError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncBadRequestErrorTypedDict": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncConflictError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncConflictErrorTypedDict": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncForbiddenError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncForbiddenErrorTypedDict": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncInternalServerErrorError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncInternalServerErrorErrorTypedDict": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncNotAcceptableError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncNotAcceptableErrorTypedDict": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncNotFoundError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncNotFoundErrorTypedDict": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncRequest": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncRequestTypedDict": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncResponse": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncResponseTypedDict": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncUnauthorizedError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncUnauthorizedErrorTypedDict": ".postbyorgbyreposyncop",
    "EventRequest": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksBadRequestError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksBadRequestErrorTypedDict": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksConflictError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksConflictErrorTypedDict": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksEventResponse": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksForbiddenError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksForbiddenErrorTypedDict": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksInternalServerErrorError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksInternalServerErrorErrorTypedDict": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksNotAcceptableError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksNotAcceptableErrorTypedDict": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksNotFoundError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksNotFoundErrorTypedDict": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksRequest": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksRequestBody": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksRequestBodyTypedDict": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksRequestTypedDict": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksResponse": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksResponseTypedDict": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksUnauthorizedError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksUnauthorizedErrorTypedDict": ".postbyorgbyrepowebhooksop",
    "PostByOrgReposAutosyncPollRequest": ".postbyorgreposop",
    "PostByOrgReposAutosyncPollRequestTypedDict": ".postbyorgreposop",
    "PostByOrgReposAutosyncResponse": ".postbyorgreposop",
    "PostByOrgReposAutosyncResponseTypedDict": ".postbyorgreposop",
    "PostByOrgReposAutosyncUnion": ".postbyorgreposop",
    "PostByOrgReposAutosyncUnionTypedDict": ".postbyorgreposop",
    "PostByOrgReposBadRequestError": ".postbyorgreposop",
    "PostByOrgReposBadRequestErrorTypedDict": ".postbyorgreposop",
    "PostByOrgReposConflictError": ".postbyorgreposop",
    "PostByOrgReposConflictErrorTypedDict": ".postbyorgreposop",
    "PostByOrgReposForbiddenError": ".postbyorgreposop",
    "PostByOrgReposForbiddenErrorTypedDict": ".postbyorgreposop",
    "PostByOrgReposInternalServerErrorError": ".postbyorgreposop",
    "PostByOrgReposInternalServerErrorErrorTypedDict": ".postbyorgreposop",
    "PostByOrgReposNotAcceptableError": ".postbyorgreposop",
    "PostByOrgReposNotAcceptableErrorTypedDict": ".postbyorgreposop",
    "PostByOrgReposNotFoundError": ".postbyorgreposop",
    "PostByOrgReposNotFoundErrorTypedDict": ".postbyorgreposop",
    "PostByOrgReposRequest": ".postbyorgreposop",
    "PostByOrgReposRequestBody": ".postbyorgreposop",
    "PostByOrgReposRequestBodyTypedDict": ".postbyorgreposop",
    "PostByOrgReposRequestTypedDict": ".postbyorgreposop",
    "PostByOrgReposResolutionStrategyRequest": ".postbyorgreposop",
    "PostByOrgReposResolutionStrategyResponse": ".postbyorgreposop",
    "PostByOrgReposResponse": ".postbyorgreposop",
    "PostByOrgReposResponseTypedDict": ".postbyorgreposop",
    "PostByOrgReposUnauthorizedError": ".postbyorgreposop",
    "PostByOrgReposUnauthorizedErrorTypedDict": ".postbyorgreposop",
    "PostByOrgReposUpstreamRequest": ".postbyorgreposop",
    "PostByOrgReposUpstreamRequestTypedDict": ".postbyorgreposop",
    "PostByOrgReposUpstreamResponse": ".postbyorgreposop",
    "PostByOrgReposUpstreamResponseTypedDict": ".postbyorgreposop",
    "Security": ".security",
    "SecurityTypedDict": ".security",
}


def dynamic_import(modname, retries=3):
    for attempt in range(retries):
        try:
            return import_module(modname, __package__)
        except KeyError:
            # Clear any half-initialized module and retry
            sys.modules.pop(modname, None)
            if attempt == retries - 1:
                break
    raise KeyError(f"Failed to import module '{modname}' after {retries} attempts")


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = dynamic_import(module_name)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = builtins.list(_dynamic_imports.keys())
    return builtins.sorted(lazy_attrs)
